miml.classifier.mi package
==========================

Submodules
----------

miml.classifier.mi.apr\_classifier module
-----------------------------------------

.. automodule:: miml.classifier.mi.apr_classifier
   :members:
   :undoc-members:
   :show-inheritance:

miml.classifier.mi.mi\_wrapper\_classifier module
-------------------------------------------------

.. automodule:: miml.classifier.mi.mi_wrapper_classifier
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: miml.classifier.mi
   :members:
   :undoc-members:
   :show-inheritance:
